==> kdesdk-3.0.1.tar.bz2: kdesdk-3.0.1/kompare/komparepart/kompareprefdlg.h <==
/***************************************************************************
                                kompareprefdlg.h  -  description
                                -------------------
        begin                   : Sun Mar 4 2001
        copyright               : (C) 2001 by Otto Bruggeman
                                  and John Firebaugh
        email                   : otto.bruggeman@home.nl
                                  jfirebaugh@kde.org
****************************************************************************/
 
/***************************************************************************
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
***************************************************************************/

#ifndef KOMPAREPREFDLG_H
#define KOMPAREPREFDLG_H

#include <kdialogbase.h>

#include "diffprefs.h"
#include "generalprefs.h"
#include "miscprefs.h"

class KomparePrefDlg : public KDialogBase
{
Q_OBJECT
public:
	KomparePrefDlg( GeneralSettings*, DiffSettings*, MiscSettings* );
	~KomparePrefDlg();

public:
	GeneralPrefs*	m_generalPage;
	DiffPrefs*	m_diffPage;
	MiscPrefs*	m_miscPage;

protected slots:
	/** No descriptions */
	virtual void slotOk();
	/** No descriptions */
	virtual void slotApply();
	/** No descriptions */
	virtual void slotHelp();
	/** No descriptions */
	virtual void slotDefault();
	/** No descriptions */
	virtual void slotCancel();
};

#endif

==> kdesdk-3.1.4.tar.bz2: kdesdk-3.1.4/kompare/komparepart/kompareprefdlg.h <==
/***************************************************************************
                                kompareprefdlg.h  -  description
                                -------------------
        begin                   : Sun Mar 4 2001
        copyright               : (C) 2001 by Otto Bruggeman
                                  and John Firebaugh
        email                   : otto.bruggeman@home.nl
                                  jfirebaugh@kde.org
****************************************************************************/
 
/***************************************************************************
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
***************************************************************************/

#ifndef KOMPAREPREFDLG_H
#define KOMPAREPREFDLG_H

#include <kdialogbase.h>

#include "diffprefs.h"
#include "generalprefs.h"
#include "miscprefs.h"

class KomparePrefDlg : public KDialogBase
{
Q_OBJECT
public:
	KomparePrefDlg( GeneralSettings*, DiffSettings*, MiscSettings* );
	~KomparePrefDlg();

public:
	GeneralPrefs*	m_generalPage;
	DiffPrefs*	m_diffPage;
//	MiscPrefs*	m_miscPage;

protected slots:
	/** No descriptions */
	virtual void slotOk();
	/** No descriptions */
	virtual void slotApply();
	/** No descriptions */
	virtual void slotHelp();
	/** No descriptions */
	virtual void slotDefault();
	/** No descriptions */
	virtual void slotCancel();
};

#endif
